# DiffMetric { #brdr.enums.DiffMetric }

```python
enums.DiffMetric()
```

Metrics to quantify the change between thematic and reference data.

## Attributes {.doc-section .doc-section-attributes}

| Name                               | Type         | Description                                            |
|------------------------------------|--------------|--------------------------------------------------------|
| AREA_CHANGE                        | [str](`str`) | Absolute change in area (m²).                          |
| AREA_PERCENTAGE_CHANGE             | [str](`str`) | Relative change in area (%).                           |
| SYMMETRICAL_AREA_CHANGE            | [str](`str`) | The area of the symmetric difference (XOR).            |
| SYMMETRICAL_AREA_PERCENTAGE_CHANGE | [str](`str`) | Symmetric difference as a percentage of original area. |
| LENGTH_CHANGE                      | [str](`str`) | Change in perimeter/length.                            |
| LENGTH_PERCENTAGE_CHANGE           | [str](`str`) | Relative change in perimeter.                          |
| LENGTH_REMOVED                     | [str](`str`) | The length of segments removed during processing.      |
| TOTAL_DISTANCE                     | [str](`str`) | Sum of displacement of all vertices.                   |
| REFERENCE_USAGE                    | [str](`str`) | The extent of reference boundaries utilized (m or m²). |